'____________________________________________________________________________________________

'                                              U S I N G   B O U N D   C O N T R O L S
'                                                                  Ron Kessler
'                                                              Created 1/17/07
'____________________________________________________________________________________________

'Updated 11/02/08

'11/02/08    Changed to a more OOP design. Added Declares and MyADO classes

'PURPOSE:
'   This application shows you how to use a combo box to select customers and display their list of purchases in a grid.
'   The program has two dataviewgrids. One shows all the customers when the program loads. Then it displays a selected
'   customer when chosen from a list.

'   The second grid shows records from the Orders table that match the chosen customer.

'DATABASE Notes:

'   This app uses customers-05.mdf. It is a SQL 2005 database with three tables: customers, orders, & products.
'   It was designed within VS2005 using SQL Server 2005 Express.
'   The app uses Integrated security to access the DB.



'ADO notes:
'1. I use the Declares and MyADO classes to manage ADO stuff.
'2. UI stuff is reserved for the form

'User Notes:

'1. To test this app, choose Joe Tran or C.Weed in the customer list to see their purchases. Not all customers have data.
'2. Make sure to edit the connection string in app.config to match the name of your SQL server.

Option Explicit On
Option Strict On

Imports System.Data                    'this is used for the dataset
Imports System.Data.SqlClient        'this gives access to SQL ADO stuff and error messages


Public Class frmMain


#Region "Lock & Load"
    Private Sub frmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        InitializeDB()


    End Sub

    ''' <summary>
    ''' This fills the combo box and customer grid upon loading the form
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub InitializeDB()

        If MYADO.FillDataSet() Then

            '---bind the combo box here 
            cboCustomers.DataSource = Declares.myDataSet.Tables("customers")
            cboCustomers.DisplayMember = "Name"                        'this is what is displayed
            cboCustomers.ValueMember = "CustID"                        'this is the key field I use to ID which customer ID is selected

            '---now bind the grid
            dgCustomers.DataSource = Declares.myDataSet
            dgCustomers.DataMember = "customers"                      'data grids bind to the name of the DS table
        End If
    End Sub

#End Region

#Region "Get Selected Customers Info"
    Private Sub btnGo_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnGo.Click
        SelectCustomer()
        ShowPurchases()

    End Sub



    ''' <summary>
    ''' This sub displays the selected customer in the top grid. Notice I use a different Dataset table (selected) for this query.
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub SelectCustomer()

        '---get the customer they chose in the combo box. We grab the CustID because it is assigned to the combobox.ValueMember prop.
        Declares.CurrentCustomerRecord = CInt(cboCustomers.SelectedValue)
        If MYADO.SelectCustomer Then
            dgCustomers.DataSource = Declares.myDataSet
            dgCustomers.DataMember = "selected"     'bind to the entire table
        End If

    End Sub

    ''' <summary>
    ''' Gets records from the Orders table based on the Customer chosen in the combo box
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub ShowPurchases()
        '---get the customer they chose in the combo box. We grab the CustID because it is assigned to the combobox.ValueMember prop.
        Declares.CurrentCustomerRecord = CInt(cboCustomers.SelectedValue)

        If MYADO.ShowCustPurchases Then
            '---bind grid to the correct DS table
            dgOrders.DataSource = Declares.myDataSet
            dgOrders.DataMember = "orders"

            '---make some alignment formatting changes in the grid
            dgOrders.Columns("Price").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            dgOrders.Columns("Tax").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            dgOrders.Columns("TotalSale").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight

            '---to show the $ sign, use c or c2 instead of n2. The n2 means format as number with 2 decimals & no $ sign
            dgOrders.Columns("Price").DefaultCellStyle.Format = "n2"
            dgOrders.Columns("Tax").DefaultCellStyle.Format = "n2"
            dgOrders.Columns("TotalSale").DefaultCellStyle.Format = "n2"
        End If

    End Sub

#End Region


End Class
